summaryrefslogtreecommitdiffstats
path: root/kjsembed/qtbindings/qcanvaspolygon_imp.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kjsembed/qtbindings/qcanvaspolygon_imp.cpp')
-rw-r--r--kjsembed/qtbindings/qcanvaspolygon_imp.cpp68
1 files changed, 34 insertions, 34 deletions
diff --git a/kjsembed/qtbindings/qcanvaspolygon_imp.cpp b/kjsembed/qtbindings/qcanvaspolygon_imp.cpp
index 4064e3f0..37109043 100644
--- a/kjsembed/qtbindings/qcanvaspolygon_imp.cpp
+++ b/kjsembed/qtbindings/qcanvaspolygon_imp.cpp
@@ -23,19 +23,19 @@
*/
namespace KJSEmbed {
-QCanvasPolygonImp::QCanvasPolygonImp( KJS::ExecState *exec, int mid, bool constructor )
+TTQCanvasPolygonImp::TQCanvasPolygonImp( KJS::ExecState *exec, int mid, bool constructor )
: JSProxyImp(exec), id(mid), cons(constructor)
{
}
-QCanvasPolygonImp::~QCanvasPolygonImp()
+TTQCanvasPolygonImp::~TQCanvasPolygonImp()
{
}
/**
* Adds bindings for static methods and enum constants to the specified Object.
*/
-void QCanvasPolygonImp::addStaticBindings( KJS::ExecState *exec, KJS::Object &object )
+void TQCanvasPolygonImp::addStaticBindings( KJS::ExecState *exec, KJS::Object &object )
{
JSProxy::MethodTable methods[] = {
@@ -43,11 +43,11 @@ void QCanvasPolygonImp::addStaticBindings( KJS::ExecState *exec, KJS::Object &ob
};
int idx = 0;
- TQCString lastName;
+ TTQCString lastName;
while( methods[idx].name ) {
if ( lastName != methods[idx].name ) {
- QCanvasPolygonImp *meth = new QCanvasPolygonImp( exec, methods[idx].id );
+ TQCanvasPolygonImp *meth = new TQCanvasPolygonImp( exec, methods[idx].id );
object.put( exec , methods[idx].name, KJS::Object(meth) );
lastName = methods[idx].name;
}
@@ -60,7 +60,7 @@ void QCanvasPolygonImp::addStaticBindings( KJS::ExecState *exec, KJS::Object &ob
/**
* Adds bindings for instance methods to the specified Object.
*/
-void QCanvasPolygonImp::addBindings( KJS::ExecState *exec, KJS::Object &object )
+void TQCanvasPolygonImp::addBindings( KJS::ExecState *exec, KJS::Object &object )
{
JSProxy::MethodTable methods[] = {
@@ -73,11 +73,11 @@ void QCanvasPolygonImp::addBindings( KJS::ExecState *exec, KJS::Object &object )
};
int idx = 0;
- TQCString lastName;
+ TTQCString lastName;
while( methods[idx].name ) {
if ( lastName != methods[idx].name ) {
- QCanvasPolygonImp *meth = new QCanvasPolygonImp( exec, methods[idx].id );
+ TQCanvasPolygonImp *meth = new TQCanvasPolygonImp( exec, methods[idx].id );
object.put( exec , methods[idx].name, KJS::Object(meth) );
lastName = methods[idx].name;
}
@@ -86,68 +86,68 @@ void QCanvasPolygonImp::addBindings( KJS::ExecState *exec, KJS::Object &object )
}
/**
* Extract a TQCanvasPolygon pointer from an Object.
*/
-TQCanvasPolygon *QCanvasPolygonImp::toQCanvasPolygon( KJS::Object &self )
+TTQCanvasPolygon *TQCanvasPolygonImp::toTQCanvasPolygon( KJS::Object &self )
{
JSObjectProxy *ob = JSProxy::toObjectProxy( self.imp() );
if ( ob ) {
- TQObject *obj = ob->object();
+ TTQObject *obj = ob->object();
if ( obj )
- return dynamic_cast<TQCanvasPolygon *>( obj );
+ return dynamic_cast<TTQCanvasPolygon *>( obj );
}
JSOpaqueProxy *op = JSProxy::toOpaqueProxy( self.imp() );
if ( !op )
return 0;
- if ( op->typeName() != "TQCanvasPolygon" )
+ if ( op->typeName() != "TTQCanvasPolygon" )
return 0;
- return op->toNative<TQCanvasPolygon>();
+ return op->toNative<TTQCanvasPolygon>();
}
/**
* Select and invoke the correct constructor.
*/
-KJS::Object QCanvasPolygonImp::construct( KJS::ExecState *exec, const KJS::List &args )
+KJS::Object TQCanvasPolygonImp::construct( KJS::ExecState *exec, const KJS::List &args )
{
switch( id ) {
case Constructor_QCanvasPolygon_1:
- return QCanvasPolygon_1( exec, args );
+ return TQCanvasPolygon_1( exec, args );
break;
default:
break;
}
- TQString msg = i18n("QCanvasPolygonCons has no constructor with id '%1',").arg(id);
+ TTQString msg = i18n("TQCanvasPolygonCons has no constructor with id '%1',").arg(id);
return throwError(exec, msg,KJS::ReferenceError);
}
-KJS::Object QCanvasPolygonImp::QCanvasPolygon_1( KJS::ExecState *exec, const KJS::List &args )
+KJS::Object TQCanvasPolygonImp::TQCanvasPolygon_1( KJS::ExecState *exec, const KJS::List &args )
{
// Unsupported parameter TQCanvas *
return KJS::Object();
- TQCanvas * arg0; // Dummy
+ TTQCanvas * arg0; // Dummy
- // We should now create an instance of the TQCanvasPolygon object
+ // We should now create an instance of the TTQCanvasPolygon object
- TQCanvasPolygon *ret = new TQCanvasPolygon(
+ TTQCanvasPolygon *ret = new TTQCanvasPolygon(
arg0 );
}
-KJS::Value QCanvasPolygonImp::call( KJS::ExecState *exec, KJS::Object &self, const KJS::List &args )
+KJS::Value TQCanvasPolygonImp::call( KJS::ExecState *exec, KJS::Object &self, const KJS::List &args )
{
- instance = QCanvasPolygonImp::toQCanvasPolygon( self );
+ instance = TQCanvasPolygonImp::toTQCanvasPolygon( self );
switch( id ) {
@@ -175,18 +175,18 @@ KJS::Value QCanvasPolygonImp::call( KJS::ExecState *exec, KJS::Object &self, con
break;
}
- TQString msg = i18n( "QCanvasPolygonImp has no method with id '%1'." ).arg( id );
+ TTQString msg = i18n( "TQCanvasPolygonImp has no method with id '%1'." ).arg( id );
return throwError(exec, msg,KJS::ReferenceError);
}
-KJS::Value QCanvasPolygonImp::setPoints_3( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
+KJS::Value TQCanvasPolygonImp::setPoints_3( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- // Unsupported parameter QPointArray
+ // Unsupported parameter TQPointArray
return KJS::Value();
- TQPointArray arg0; // Dummy
+ TTQPointArray arg0; // Dummy
instance->setPoints(
arg0 );
@@ -194,15 +194,15 @@ KJS::Value QCanvasPolygonImp::setPoints_3( KJS::ExecState *exec, KJS::Object &ob
}
-KJS::Value QCanvasPolygonImp::points_4( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
+KJS::Value TQCanvasPolygonImp::points_4( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
instance->points( );
- return KJS::Value(); // Returns 'QPointArray'
+ return KJS::Value(); // Returns 'TQPointArray'
}
-KJS::Value QCanvasPolygonImp::moveBy_5( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
+KJS::Value TQCanvasPolygonImp::moveBy_5( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
double arg0 = extractDouble(exec, args, 0);
@@ -216,15 +216,15 @@ KJS::Value QCanvasPolygonImp::moveBy_5( KJS::ExecState *exec, KJS::Object &obj,
}
-KJS::Value QCanvasPolygonImp::areaPoints_6( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
+KJS::Value TQCanvasPolygonImp::areaPoints_6( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
instance->areaPoints( );
- return KJS::Value(); // Returns 'QPointArray'
+ return KJS::Value(); // Returns 'TQPointArray'
}
-KJS::Value QCanvasPolygonImp::rtti_7( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
+KJS::Value TQCanvasPolygonImp::rtti_7( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
int ret;
@@ -86,68 +86,68 @@ void QCanvasPolygonImp::addBindings( KJS::ExecState *exec, KJS::Object &object )
}
/**
- * Extract a TQCanvasPolygon pointer from an Object.
+ * Extract a TTQCanvasPolygon pointer from an Object.
*/
@@ -86,68 +86,68 @@ void QCanvasPolygonImp::addBindings( KJS::ExecState *exec, KJS::Object &object )
{
- // Unsupported parameter TQCanvas *
+ // Unsupported parameter TTQCanvas *
return KJS::Object();